@@ -5,7 +5,7 @@ use warnings;
 
 require Exporter;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 our @ISA = qw(Exporter);
 
@@ -41,22 +41,29 @@ CLOCK_MONOTONIC_PRECISE CLOCK_MONOTONIC_RAW CLOCK_PROCESS_CPUTIME_ID
 CLOCK_REALTIME CLOCK_REALTIME_COARSE CLOCK_REALTIME_FAST
 CLOCK_REALTIME_PRECISE CLOCK_SOFTTIME CLOCK_THREAD_CPUTIME_ID CLOCK_UPTIME
 CLOCK_UPTIME_FAST CLOCK_UPTIME_PRECISE _CS_GNU_LIBC_VERSION
-_CS_GNU_LIBPTHREAD_VERSION _CS_PATH DEAD_PROCESS FNM_CASEFOLD FNM_FILE_NAME
-FNM_LEADING_DIR FNM_NOESCAPE FNM_NOMATCH FNM_PATHNAME FNM_PERIOD FP_INFINITE
-FP_NAN FP_NORMAL FP_SUBNORMAL FP_ZERO INIT_PROCESS ITIMER_PROF ITIMER_REAL
-ITIMER_VIRTUAL LOGIN_PROCESS NEW_TIME O_CLOEXEC O_DIRECTORY O_EXEC OLD_TIME
-O_NOFOLLOW O_RSYNC O_SEARCH O_SYNC O_TMPFILE O_TTY_INIT RTLD_GLOBAL RTLD_LAZY
-RTLD_LOCAL RTLD_NOW RUN_LVL TIMER_ABSTIME USER_PROCESS UTIME_NOW UTIME_OMIT
+_CS_GNU_LIBPTHREAD_VERSION _CS_PATH DEAD_PROCESS F_DUPFD F_DUPFD_CLOEXEC
+F_GETFD F_SETFD F_GETFL F_SETFL F_GETLK F_SETLK F_SETLKW F_GETOWN F_SETOWN
+F_RDLCK F_UNLCK F_WRLCK FD_CLOEXEC FNM_CASEFOLD FNM_FILE_NAME FNM_LEADING_DIR
+FNM_NOESCAPE FNM_NOMATCH FNM_PATHNAME FNM_PERIOD FP_INFINITE FP_NAN FP_NORMAL
+FP_SUBNORMAL FP_ZERO INIT_PROCESS ITIMER_PROF ITIMER_REAL ITIMER_VIRTUAL
+LOGIN_PROCESS NEW_TIME O_ACCMODE O_APPEND O_CLOEXEC O_CREAT O_DIRECTORY
+O_DSYNC O_EXEC O_NOCTTY O_NOFOLLOW O_NONBLOCK O_RDONLY O_RDWR O_RSYNC O_SEARCH
+O_SYNC O_TMPFILE O_TRUNC O_TTY_INIT O_WRONLY OLD_TIME POSIX_FADV_NORMAL
+POSIX_FADV_SEQUENTIAL POSIX_FADV_RANDOM POSIX_FADV_NOREUSE POSIX_FADV_WILLNEED
+POSIX_FADV_DONTNEED RTLD_GLOBAL RTLD_LAZY RTLD_LOCAL RTLD_NOW RUN_LVL SEEK_SET
+SEEK_CUR SEEK_END TIMER_ABSTIME USER_PROCESS UTIME_NOW UTIME_OMIT
 
 );
 
 our %EXPORT_TAGS = (
   'at'    => [grep(/^AT_/, @EXPORT_OK), grep(/at$/ && !/^l?stat$/, @EXPORT_OK)],
   'id'    => [grep /^[gs]et.+id$/, @EXPORT_OK],
-  'clock' => [grep /^clock/i, @EXPORT_OK],
+  'is'    => [grep /^is/, @EXPORT_OK],
   'rw'    => [qw(read write readv writev)],
   'prw'   => [qw(pread preadv pwrite pwritev)],
-  'is'    => [grep /^is/, @EXPORT_OK],
+  'clock' => [grep /^clock/i, @EXPORT_OK],
+  'fcntl' => [grep /^(?:F|FD|O|POSIX_FADV)_/, @EXPORT_OK],
+  'fnm'   => [grep(/^FNM_/, @EXPORT_OK), 'fnmatch']
 );
 
 our $AUTOLOAD;
